@@ -165,18 +165,4 @@ class DataArrayControllerLayout(QtGui.QGridLayout):
                 parent._update_currval
             )
 
-# ----------------------------------------------------------------------------------
-
-from iautil.plotting.image_tool import ImageTool
-
-it = ImageTool(
-    xr.DataArray(
-        [
-            [1234, 3456, 3456], 
-            [2345, 56, 456], 
-            [3456, 345, 4567]
-        ]
-    )
-)
-
-it.show()
+# ----------------------------------------------------------------------------------
\ No newline at end of file
